@@ -17,7 +17,7 @@ import (
 	"github.com/confluentinc/cli/internal/pkg/output"
 )
 
-func (c *command) newKafkaTopicConsumeCommand() *cobra.Command {
+func (c *Command) newKafkaTopicConsumeCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "consume <topic>",
 		Args:  cobra.ExactArgs(1),
@@ -47,7 +47,7 @@ func (c *command) newKafkaTopicConsumeCommand() *cobra.Command {
 	return cmd
 }
 
-func (c *command) kafkaTopicConsume(cmd *cobra.Command, args []string) error {
+func (c *Command) kafkaTopicConsume(cmd *cobra.Command, args []string) error {
 	printKey, err := cmd.Flags().GetBool("print-key")
 	if err != nil {
 		return err
