@@ -29,7 +29,7 @@ func (c *command) list(cmd *cobra.Command, _ []string) error {
 	list := output.NewList(cmd)
 	for _, organization := range organizations {
 		list.Add(&out{
-			IsCurrent: organization.GetId() == c.Context.GetOrganization().GetResourceId(),
+			IsCurrent: organization.GetId() == c.Context.GetCurrentOrganization(),
 			Id:        organization.GetId(),
 			Name:      organization.GetDisplayName(),
 		})
