@@ -15,7 +15,7 @@ import (
 	"github.com/confluentinc/cli/internal/pkg/examples"
 )
 
-func (c *command) newCreateCommand(enableSourceCode bool) *cobra.Command {
+func (c *command) newCreateCommand() *cobra.Command {
 	cmd := &cobra.Command{
 		Use:   "create",
 		Short: "Create a new pipeline.",
@@ -32,21 +32,16 @@ func (c *command) newCreateCommand(enableSourceCode bool) *cobra.Command {
 	cmd.Flags().String("name", "", "Name of the pipeline.")
 	cmd.Flags().String("description", "", "Description of the pipeline.")
 	pcmd.AddKsqlClusterFlag(cmd, c.AuthenticatedCLICommand)
-	if enableSourceCode {
-		cmd.Flags().String("sql-file", "", "Path to a KSQL file containing the pipeline's source code.")
-		cmd.Flags().StringArray("secret", []string{}, "A named secret that can be referenced in pipeline source code, e.g. \"secret_name=secret_content\".\n"+
-			"This flag can be supplied multiple times. The secret mapping must have the format <secret-name>=<secret-value>,\n"+
-			"where <secret-name> consists of 1-128 lowercase, uppercase, numeric or underscore characters but may not begin with a digit.\n"+
-			"The <secret-value> can be of any format but may not be empty.")
-	}
+	cmd.Flags().String("sql-file", "", "Path to a KSQL file containing the pipeline's source code.")
+	cmd.Flags().StringArray("secret", []string{}, "A named secret that can be referenced in pipeline source code, e.g. \"secret_name=secret_content\".\n"+
+		"This flag can be supplied multiple times. The secret mapping must have the format <secret-name>=<secret-value>,\n"+
+		"where <secret-name> consists of 1-128 lowercase, uppercase, numeric or underscore characters but may not begin with a digit.\n"+
+		"The <secret-value> can be of any format but may not be empty.")
 	pcmd.AddOutputFlag(cmd)
 	pcmd.AddClusterFlag(cmd, c.AuthenticatedCLICommand)
 	pcmd.AddEnvironmentFlag(cmd, c.AuthenticatedCLICommand)
 
-	if enableSourceCode {
-		cobra.CheckErr(cmd.MarkFlagFilename("sql-file", "sql"))
-	}
-
+	cobra.CheckErr(cmd.MarkFlagFilename("sql-file", "sql"))
 	cobra.CheckErr(cmd.MarkFlagRequired("name"))
 
 	return cmd
