@@ -6,6 +6,7 @@ import (
 	"github.com/spf13/cobra"
 
 	pcmd "github.com/confluentinc/cli/internal/pkg/cmd"
+	"github.com/confluentinc/cli/internal/pkg/errors"
 	"github.com/confluentinc/cli/internal/pkg/examples"
 )
 
@@ -14,7 +15,6 @@ func (c *command) newSchemaDescribeCommandOnPrem() *cobra.Command {
 		Use:         "describe [id]",
 		Short:       "Get schema either by schema ID, or by subject/version.",
 		Args:        cobra.MaximumNArgs(1),
-		PreRunE:     c.preDescribe,
 		RunE:        c.schemaDescribeOnPrem,
 		Annotations: map[string]string{pcmd.RunRequirement: pcmd.RequireOnPremLogin},
 		Example: examples.BuildExampleString(
@@ -39,6 +39,22 @@ func (c *command) newSchemaDescribeCommandOnPrem() *cobra.Command {
 }
 
 func (c *command) schemaDescribeOnPrem(cmd *cobra.Command, args []string) error {
+	subject, err := cmd.Flags().GetString("subject")
+	if err != nil {
+		return err
+	}
+
+	version, err := cmd.Flags().GetString("version")
+	if err != nil {
+		return err
+	}
+
+	if len(args) > 0 && (subject != "" || version != "") {
+		return errors.New(errors.BothSchemaAndSubjectErrorMsg)
+	} else if len(args) == 0 && (subject == "" || version == "") {
+		return errors.New(errors.SchemaOrSubjectErrorMsg)
+	}
+
 	srClient, ctx, err := GetSrApiClientWithToken(cmd, c.Version, c.AuthToken())
 	if err != nil {
 		return err
