@@ -263,7 +263,7 @@ func (c *InputController) printResultToSTDOUT(statementResults *types.StatementR
 	variablePadding := (len(statementResults.Headers) - 1) * 3 // column separator
 	totalAvailableChars := windowSize - fixedPadding - variablePadding
 
-	materializedStatementResults := results.NewMaterializedStatementResults(statementResults.GetHeaders(), maxResultsCapacity)
+	materializedStatementResults := types.NewMaterializedStatementResults(statementResults.GetHeaders(), maxResultsCapacity)
 	materializedStatementResults.Append(statementResults.GetRows()...)
 	columnWidths := materializedStatementResults.GetMaxWidthPerColum()
 	columnWidths = results.GetTruncatedColumnWidths(columnWidths, totalAvailableChars)
@@ -288,7 +288,7 @@ func (c *InputController) Prompt() prompt.IPrompt {
 		AddCompleter(autocomplete.SetCompleter).
 		AddCompleter(autocomplete.ShowCompleter).
 		AddCompleter(autocomplete.GenerateHistoryCompleter(c.History.Data)).
-		AddCompleter(autocomplete.GenerateDocsCompleter()).
+		// AddCompleter(autocomplete.GenerateDocsCompleter()).
 		BuildCompleter()
 
 	return prompt.New(
