@@ -35,5 +35,21 @@ type TableControllerInterface interface {
 	AppInputCapture(event *tcell.EventKey) *tcell.EventKey
 	Init(statement ProcessedStatement)
 	SetRunInteractiveInputCallback(func())
-	GetActionForShortcut(shortcut string) func()
+}
+
+type FetchControllerInterface interface {
+	GetFetchState() FetchState
+	IsTableMode() bool
+	ToggleTableMode()
+	ToggleAutoRefresh()
+	IsAutoRefreshRunning() bool
+	FetchNextPage()
+	JumpToLastPage()
+	GetHeaders() []string
+	GetMaxWidthPerColumn() []int
+	GetResultsIterator(bool) MaterializedStatementResultsIterator
+	ForEach(func(rowIdx int, row *StatementResultRow))
+	Init(statement ProcessedStatement)
+	Close()
+	SetAutoRefreshCallback(func())
 }
